@@ -1,7 +1,7 @@
 import logging
 
-from rasa import version
-from rasa.api import run, train, test
+from rasa import version  # noqa: F401
+from rasa.api import run, train, test  # noqa: F401
 
 # define the version before the other imports since these need it
 __version__ = version.__version__
