@@ -7,6 +7,7 @@ from rasa.cli.arguments.default_arguments import (
     add_nlu_data_param,
     add_out_param,
     add_domain_param,
+    add_endpoint_param,
 )
 from rasa.graph_components.providers.training_tracker_provider import (
     TrainingTrackerProvider,
@@ -33,6 +34,9 @@ def set_train_arguments(parser: argparse.ArgumentParser) -> None:
     add_persist_nlu_data_param(parser)
     add_force_param(parser)
     add_finetune_params(parser)
+    add_endpoint_param(
+        parser, help_text="Configuration file for the connectors as a yml file."
+    )
 
 
 def set_train_core_arguments(parser: argparse.ArgumentParser) -> None:
