@@ -1,9 +1,10 @@
+from __future__ import annotations
 import asyncio
+from contextlib import asynccontextmanager
 import json
 import logging
 import os
 
-from async_generator import asynccontextmanager
 from typing import AsyncGenerator, Dict, Optional, Text, Union
 
 from rasa.shared.exceptions import RasaException, ConnectionException
@@ -37,10 +38,11 @@ class LockError(RasaException):
 
 
 class LockStore:
-    @staticmethod
-    def create(obj: Union["LockStore", EndpointConfig, None]) -> "LockStore":
-        """Factory to create a lock store."""
+    """Base class for ticket locks."""
 
+    @staticmethod
+    def create(obj: Union[LockStore, EndpointConfig, None]) -> LockStore:
+        """Factory to create a lock store."""
         if isinstance(obj, LockStore):
             return obj
 
@@ -52,22 +54,18 @@ class LockStore:
     @staticmethod
     def create_lock(conversation_id: Text) -> TicketLock:
         """Create a new `TicketLock` for `conversation_id`."""
-
         return TicketLock(conversation_id)
 
     def get_lock(self, conversation_id: Text) -> Optional[TicketLock]:
         """Fetch lock for `conversation_id` from storage."""
-
         raise NotImplementedError
 
     def delete_lock(self, conversation_id: Text) -> None:
         """Delete lock for `conversation_id` from storage."""
-
         raise NotImplementedError
 
     def save_lock(self, lock: TicketLock) -> None:
         """Commit `lock` to storage."""
-
         raise NotImplementedError
 
     def issue_ticket(
@@ -296,9 +294,8 @@ class InMemoryLockStore(LockStore):
 
 def _create_from_endpoint_config(
     endpoint_config: Optional[EndpointConfig] = None,
-) -> "LockStore":
+) -> LockStore:
     """Given an endpoint configuration, create a proper `LockStore` object."""
-
     if (
         endpoint_config is None
         or endpoint_config.type is None
@@ -306,7 +303,7 @@ def _create_from_endpoint_config(
     ):
         # this is the default type if no lock store type is set
 
-        lock_store = InMemoryLockStore()
+        lock_store: LockStore = InMemoryLockStore()
     elif endpoint_config.type == "redis":
         lock_store = RedisLockStore(host=endpoint_config.url, **endpoint_config.kwargs)
     else:
@@ -319,9 +316,8 @@ def _create_from_endpoint_config(
 
 def _load_from_module_name_in_endpoint_config(
     endpoint_config: EndpointConfig,
-) -> "LockStore":
+) -> LockStore:
     """Retrieve a `LockStore` based on its class name."""
-
     try:
         lock_store_class = rasa.shared.utils.common.class_from_module_path(
             endpoint_config.type
