@@ -83,6 +83,7 @@ def configure_app(
     enable_api: bool = True,
     response_timeout: int = constants.DEFAULT_RESPONSE_TIMEOUT,
     jwt_secret: Optional[Text] = None,
+    jwt_private_key: Optional[Text] = None,
     jwt_method: Optional[Text] = None,
     route: Optional[Text] = "/webhooks/",
     port: int = constants.DEFAULT_SERVER_PORT,
@@ -93,6 +94,7 @@ def configure_app(
     syslog_address: Optional[Text] = None,
     syslog_port: Optional[int] = None,
     syslog_protocol: Optional[Text] = None,
+    request_timeout: Optional[int] = None,
 ) -> Sanic:
     """Run the agent."""
     rasa.core.utils.configure_file_logging(
@@ -105,6 +107,7 @@ def configure_app(
             auth_token=auth_token,
             response_timeout=response_timeout,
             jwt_secret=jwt_secret,
+            jwt_private_key=jwt_private_key,
             jwt_method=jwt_method,
             endpoints=endpoints,
         )
@@ -134,6 +137,7 @@ def configure_app(
             await console.record_messages(
                 server_url=constants.DEFAULT_SERVER_FORMAT.format("http", port),
                 sender_id=conversation_id,
+                request_timeout=request_timeout,
             )
 
             logger.info("Killing Sanic server now.")
@@ -155,6 +159,7 @@ def serve_application(
     enable_api: bool = True,
     response_timeout: int = constants.DEFAULT_RESPONSE_TIMEOUT,
     jwt_secret: Optional[Text] = None,
+    jwt_private_key: Optional[Text] = None,
     jwt_method: Optional[Text] = None,
     endpoints: Optional[AvailableEndpoints] = None,
     remote_storage: Optional[Text] = None,
@@ -168,6 +173,7 @@ def serve_application(
     syslog_address: Optional[Text] = None,
     syslog_port: Optional[int] = None,
     syslog_protocol: Optional[Text] = None,
+    request_timeout: Optional[int] = None,
 ) -> None:
     """Run the API entrypoint."""
     if not channel and not credentials:
@@ -182,6 +188,7 @@ def serve_application(
         enable_api,
         response_timeout,
         jwt_secret,
+        jwt_private_key,
         jwt_method,
         port=port,
         endpoints=endpoints,
@@ -191,6 +198,7 @@ def serve_application(
         syslog_address=syslog_address,
         syslog_port=syslog_port,
         syslog_protocol=syslog_protocol,
+        request_timeout=request_timeout,
     )
 
     ssl_context = server.create_ssl_context(
