@@ -10,7 +10,7 @@ from typing import Any, Optional, Text, Dict
 from rasa.shared.exceptions import FileNotFoundException
 import rasa.shared.utils.io
 import rasa.utils.io
-from rasa.constants import DEFAULT_REQUEST_TIMEOUT
+from rasa.core.constants import DEFAULT_REQUEST_TIMEOUT
 
 
 logger = logging.getLogger(__name__)
@@ -132,13 +132,14 @@ class EndpointConfig:
         method: Text = "post",
         subpath: Optional[Text] = None,
         content_type: Optional[Text] = "application/json",
+        compress: bool = False,
         **kwargs: Any,
     ) -> Optional[Any]:
         """Send a HTTP request to the endpoint. Return json response, if available.
 
         All additional arguments will get passed through
-        to aiohttp's `session.request`."""
-
+        to aiohttp's `session.request`.
+        """
         # create the appropriate headers
         headers = {}
         if content_type:
@@ -166,6 +167,7 @@ class EndpointConfig:
                 url,
                 headers=headers,
                 params=self.combine_parameters(kwargs),
+                compress=compress,
                 ssl=sslcontext,
                 **kwargs,
             ) as response:
