@@ -2,9 +2,12 @@ import logging
 from typing import List, Optional, Text, Tuple, Callable, Union, Any
 import tensorflow as tf
 import tensorflow_addons as tfa
+
+# TODO: The following is not (yet) available via tf.keras
+from keras.utils.control_flow_util import smart_cond
+import tensorflow.keras.backend as K
+
 import rasa.utils.tensorflow.crf
-from tensorflow.python.layers.utils import smart_cond
-from tensorflow.keras import backend as K
 from rasa.utils.tensorflow.constants import (
     SOFTMAX,
     MARGIN,
@@ -1154,7 +1157,7 @@ class SingleLabelDotProductLoss(DotProductLoss):
             )
 
     # noinspection PyMethodOverriding
-    def call(
+    def call(  # type: ignore[override]
         self,
         inputs_embed: tf.Tensor,
         labels_embed: tf.Tensor,
@@ -1253,7 +1256,7 @@ class MultiLabelDotProductLoss(DotProductLoss):
             model_confidence=model_confidence,
         )
 
-    def call(
+    def call(  # type: ignore[override]
         self,
         batch_inputs_embed: tf.Tensor,
         batch_labels_embed: tf.Tensor,
